package Source::Shared::Utils::Downloader;

# ABSTRACT: shared url downloader

use strict;
use warnings;
use Carp;
use File::Basename;
use File::Path qw(make_path remove_tree);
require Exporter;
our @ISA = qw(Exporter);
our @EXPORT_OK = qw(cached_download named_cache_download);

our $VERSION=0.001;
our $verbose=1;

our $default_cachedir='in';

sub named_cache_download {
    my ($url,$cachename,$cachedir)=@_;
    $cachedir//=$default_cachedir;
    my $namedsubdir=$cachedir.'/'.$cachename;
    return &cached_download($url,$namedsubdir);
}

sub cached_download {
    my ($url,$cachedir)=@_;
    $cachedir//=$default_cachedir;
    print STDERR "DEBUG: cached_download: $url -> $cachedir\n" if $verbose>2;
    my $filename=basename($url);
    $filename=~s/\?.*$//;
    make_path($cachedir);
    my $file=$cachedir.'/'.$filename;
    return $file if -e $file and -s $file;
    unlink $file;
    if ($url =~ m!^rsync://!) {
	my $rsync_url=$url;
	$rsync_url =~ s!^rsync://!! if $rsync_url =~ /::/;
	if ($verbose) {
	    &__run(qw/rsync -avp/, $rsync_url, $file);
	} else {
	    &__run(qw/rsync -ap/, $rsync_url, $file);
	}
    } else {
	if ($verbose) {
	    &__run(qw/wget -nv -O/, $file, $url);
	} else {
	    &__run(qw/wget -q -nv -O/, $file, $url);
	}
    }
    unlink $file if -z $file;
    die "Downloader: $url: download failed" unless -e $file;
    return $file;
}

sub __run {
    print STDERR "running: ", join(' ',@_),"\n" if $verbose>1;
    system(@_)==0 or die "Error: ",join(' ',@_), " failed.";
}

1;

__END__
